==> qtjambi-qt3dcore-5.15.6-sources.jar: io/qt/qt3d/core/QBackendNodeMapper.java <==
package io.qt.qt3d.core;


/**
 * <p>Creates and maps backend nodes to their respective frontend nodes</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qbackendnodemapper.html">Qt3DCore::QBackendNodeMapper</a></p>
 */
public abstract class QBackendNodeMapper extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QBackendNodeMapper {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.qt3d.core.QBackendNode create(io.qt.qt3d.core.QNodeCreatedChange change){
            return create_native_cref_QSharedPointer_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), change);
        }
        @io.qt.QtUninvokable
        private native io.qt.qt3d.core.QBackendNode create_native_cref_QSharedPointer_constfct(long __this__nativeId, io.qt.qt3d.core.QNodeCreatedChange change);
        
        
        @Override
        @io.qt.QtUninvokable
        public void destroy(io.qt.qt3d.core.QNodeId id){
            destroy_native_Qt3DCore_QNodeId_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
        }
        @io.qt.QtUninvokable
        private native void destroy_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long id);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.qt3d.core.QBackendNode get(io.qt.qt3d.core.QNodeId id){
            return get_native_Qt3DCore_QNodeId_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
        }
        @io.qt.QtUninvokable
        private native io.qt.qt3d.core.QBackendNode get_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long id);
        
    }
    
    
    public QBackendNodeMapper(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QBackendNodeMapper instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qbackendnodemapper.html#create">Qt3DCore::QBackendNodeMapper::create(Qt3DCore::QNodeCreatedChangeBasePtr)const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.qt3d.core.QBackendNode create(io.qt.qt3d.core.QNodeCreatedChange change);
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QBackendNode create_native_cref_QSharedPointer_constfct(long __this__nativeId, io.qt.qt3d.core.QNodeCreatedChange change);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qbackendnodemapper.html#destroy">Qt3DCore::QBackendNodeMapper::destroy(Qt3DCore::QNodeId)const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void destroy(io.qt.qt3d.core.QNodeId id);
    
    @io.qt.QtUninvokable
    private native void destroy_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qbackendnodemapper.html#get">Qt3DCore::QBackendNodeMapper::get(Qt3DCore::QNodeId)const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.qt3d.core.QBackendNode get(io.qt.qt3d.core.QNodeId id);
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QBackendNode get_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long id);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QBackendNodeMapper(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QBackendNodeMapper.java <==
package io.qt.qt3d.core;


/**
 * <p>Creates and maps backend nodes to their respective frontend nodes</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qbackendnodemapper.html">Qt3DCore::QBackendNodeMapper</a></p>
 */
public abstract class QBackendNodeMapper extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QBackendNodeMapper {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.qt3d.core.QBackendNode create(io.qt.qt3d.core.QNodeCreatedChange change){
            return create_native_cref_QSharedPointer_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), change);
        }
        @io.qt.QtUninvokable
        private native io.qt.qt3d.core.QBackendNode create_native_cref_QSharedPointer_constfct(long __this__nativeId, io.qt.qt3d.core.QNodeCreatedChange change);
        
        
        @Override
        @io.qt.QtUninvokable
        public void destroy(io.qt.qt3d.core.QNodeId id){
            destroy_native_Qt3DCore_QNodeId_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
        }
        @io.qt.QtUninvokable
        private native void destroy_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long id);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.qt3d.core.QBackendNode get(io.qt.qt3d.core.QNodeId id){
            return get_native_Qt3DCore_QNodeId_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
        }
        @io.qt.QtUninvokable
        private native io.qt.qt3d.core.QBackendNode get_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long id);
        
    }
    
    
    public QBackendNodeMapper(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QBackendNodeMapper instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qbackendnodemapper.html#create">Qt3DCore::QBackendNodeMapper::create(Qt3DCore::QNodeCreatedChangeBasePtr)const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.qt3d.core.QBackendNode create(io.qt.qt3d.core.QNodeCreatedChange change);
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QBackendNode create_native_cref_QSharedPointer_constfct(long __this__nativeId, io.qt.qt3d.core.QNodeCreatedChange change);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qbackendnodemapper.html#destroy">Qt3DCore::QBackendNodeMapper::destroy(Qt3DCore::QNodeId)const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void destroy(io.qt.qt3d.core.QNodeId id);
    
    @io.qt.QtUninvokable
    private native void destroy_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qbackendnodemapper.html#get">Qt3DCore::QBackendNodeMapper::get(Qt3DCore::QNodeId)const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.qt3d.core.QBackendNode get(io.qt.qt3d.core.QNodeId id);
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QBackendNode get_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long id);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QBackendNodeMapper(QPrivateConstructor p) { super(p); } 
    
}
